
/*
 * Copyright (c) 2005, Arnaud KLEIN
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */ 
 
#include "EntriesFilter.h"

/* Constructor */
cEntriesFilter::cEntriesFilter(const vector<cLogEntry>& vectLogEntries, const cOptions& options) : m_vectInputEntries(vectLogEntries), m_vectOutputEntries(), m_options(options) 
{
}


/* Apply filters */
void cEntriesFilter::ApplyFilters()
{
	for(vector<cLogEntry>::const_iterator it=m_vectInputEntries.begin(); it!=m_vectInputEntries.end(); it++)
	{
		const cLogEntry& entry=*it;
	
		// Action
		if (!IsInFilter(entry.GetAction(), m_options.GetFilterAction()))
			continue;

		// Direction
		if (!IsInFilter(entry.GetDirection(), m_options.GetFilterDirection()))
			continue;

		// Protocol
		if (!IsInFilter(entry.GetProtocol(), m_options.GetFilterProtocol()))
			continue;

		// Add entry to output list
		if (m_options.GetReverseSort())
			m_vectOutputEntries.insert(m_vectOutputEntries.begin(), entry);
		else
			m_vectOutputEntries.push_back(entry);	
	}
}


/* Check if given filter is included in filters list */
bool cEntriesFilter::IsInFilter(u_int8_t filter, const vector<u_int8_t>& vectFilters) const
{
	if (vectFilters.empty())
		return true;

	for(vector<u_int8_t>::const_iterator it=vectFilters.begin(); it!=vectFilters.end(); it++)
	{
		if (*it == filter)
			return true;
	}

	return false;
}


